Struct wasmer_engine_universal::CodeMemory [−][src]
pub struct CodeMemory { /* fields omitted */ }Expand description
Memory manager for executable code.
Implementations
Mutably get the UnwindRegistry.
Allocate a single contiguous block of memory for the functions and custom sections, and copy the data in place.