pub struct UniversalExecutable { /* private fields */ }Expand description
A wasm module compiled to some shape, ready to be loaded with UniversalEngine to produce an
UniversalArtifact.
This is the result obtained after validating and compiling a WASM module with any of the
supported compilers. This type falls in-between a module and Artifact.